##  Configuring Relation Mapping
Follow these steps:
  1. On the ServiceNow configuration page, under Relation Mapping, locate a relation mapping between applications and IT components (hardware or software category).
  2. Hover over the mapping and click Configuration on the right side.
![Configuration of Relation Mappings](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f28d07a441014878ccbff0251402b_LowRes.png)
Configuration of Relation Mappings
  3. In the overlay that appears, under ServiceNow Relation, choose a relation type from the Relation (Required) list. A preview shows how the system will detect relations between cmdb_ci_hardware and the table representing hardware/software.
![Relation Mapping Between Applications and Software Items](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754a1ea7a4410149f54ddae8efb8251_LowRes.png)
Relation Mapping Between Applications and Software Items
  4. Save your changes.


YesNo
Send
